@@ -78,10 +78,10 @@ def add_todo(task_text, expected_duration, project_id=0):
     tm = time.localtime()
     
     if expected_duration is None:
-        tar_date = f"{tm.tm_year}-{tm.tm_mon:02d}-{tm.tm_mday+1}"
+        tar_date = f"{tm.tm_year}-{tm.tm_mon:02d}-{tm.tm_mday+1:02d}"
     else:
         day = tm.tm_mday+int(expected_duration)
-        tar_date = f"{tm.tm_year}-{tm.tm_mon:02d}-{day}"
+        tar_date = f"{tm.tm_year}-{tm.tm_mon:02d}-{day:02d}"
     
     
     client = get_client()
